@@ -33,6 +33,7 @@ GIT_VERSION_REGEX = re.compile(r"^git\sversion\s(?P<version>\d+(.\d+)*)")
 
 execution_lock = tornado.locks.Lock()
 
+
 async def execute(
     cmdline: "List[str]",
     cwd: "str",
@@ -61,7 +62,12 @@ async def execute(
     ) -> "Tuple[int, str, str]":
         try:
             p = pexpect.spawn(
-                cmdline[0], cmdline[1:], cwd=cwd, env=env, encoding="utf-8", timeout=None
+                cmdline[0],
+                cmdline[1:],
+                cwd=cwd,
+                env=env,
+                encoding="utf-8",
+                timeout=None,
             )
 
             # We expect a prompt from git
@@ -101,14 +107,16 @@ async def execute(
         return (process.returncode, output.decode("utf-8"), error.decode("utf-8"))
 
     try:
-        await execution_lock.acquire(timeout=datetime.timedelta(seconds=MAX_WAIT_FOR_EXECUTE_S))
+        await execution_lock.acquire(
+            timeout=datetime.timedelta(seconds=MAX_WAIT_FOR_EXECUTE_S)
+        )
     except tornado.util.TimeoutError:
         return (1, "", "Unable to get the lock on the directory")
 
     try:
         # Ensure our execution operation will succeed by first checking and waiting for the lock to be removed
         time_slept = 0
-        lockfile = os.path.join(cwd, '.git', 'index.lock')
+        lockfile = os.path.join(cwd, ".git", "index.lock")
         while os.path.exists(lockfile) and time_slept < MAX_WAIT_FOR_LOCK_S:
             await tornado.gen.sleep(CHECK_LOCK_INTERVAL_S)
             time_slept += CHECK_LOCK_INTERVAL_S
@@ -129,9 +137,15 @@ async def execute(
             code, output, error = await current_loop.run_in_executor(
                 None, call_subprocess, cmdline, cwd, env
             )
-        log_output = output[:MAX_LOG_OUTPUT] + "..." if len(output) > MAX_LOG_OUTPUT else output
-        log_error = error[:MAX_LOG_OUTPUT] + "..." if len(error) > MAX_LOG_OUTPUT else error
-        get_logger().debug("Code: {}\nOutput: {}\nError: {}".format(code, log_output, log_error))
+        log_output = (
+            output[:MAX_LOG_OUTPUT] + "..." if len(output) > MAX_LOG_OUTPUT else output
+        )
+        log_error = (
+            error[:MAX_LOG_OUTPUT] + "..." if len(error) > MAX_LOG_OUTPUT else error
+        )
+        get_logger().debug(
+            "Code: {}\nOutput: {}\nError: {}".format(code, log_output, log_error)
+        )
     except BaseException:
         get_logger().warning("Fail to execute {!s}".format(cmdline), exc_info=True)
     finally:
@@ -188,11 +202,13 @@ class Git:
             else:
                 raw = output.strip()
                 s = CONFIG_PATTERN.split(raw)
-                response["options"] = {k:v for k, v in zip(s[1::2], s[2::2])}
+                response["options"] = {k: v for k, v in zip(s[1::2], s[2::2])}
 
         return response
 
-    async def changed_files(self, current_path, base=None, remote=None, single_commit=None):
+    async def changed_files(
+        self, current_path, base=None, remote=None, single_commit=None
+    ):
         """Gets the list of changed files between two Git refs, or the files changed in a single commit
 
         There are two reserved "refs" for the base
@@ -227,7 +243,9 @@ class Git:
 
         response = {}
         try:
-            code, output, error = await execute(cmd, cwd=os.path.join(self.root_dir, current_path))
+            code, output, error = await execute(
+                cmd, cwd=os.path.join(self.root_dir, current_path)
+            )
         except subprocess.CalledProcessError as e:
             response["code"] = e.returncode
             response["message"] = e.output.decode("utf-8")
@@ -282,7 +300,8 @@ class Git:
         """
         cmd = ["git", "status", "--porcelain", "-u", "-z"]
         code, my_output, my_error = await execute(
-            cmd, cwd=os.path.join(self.root_dir, current_path),
+            cmd,
+            cwd=os.path.join(self.root_dir, current_path),
         )
 
         if code != 0:
@@ -299,10 +318,11 @@ class Git:
             "--numstat",
             "-z",
             "--cached",
-            "4b825dc642cb6eb9a060e54bf8d69288fbee4904"
+            "4b825dc642cb6eb9a060e54bf8d69288fbee4904",
         ]
         text_code, text_output, _ = await execute(
-            command, cwd=os.path.join(self.root_dir, current_path),
+            command,
+            cwd=os.path.join(self.root_dir, current_path),
         )
 
         are_binary = dict()
@@ -315,14 +335,16 @@ class Git:
         line_iterable = (line for line in strip_and_split(my_output) if line)
         for line in line_iterable:
             name = line[3:]
-            result.append({
-                "x": line[0],
-                "y": line[1],
-                "to": name,
-                # if file was renamed, next line contains original path
-                "from": next(line_iterable) if line[0]=='R' else name,
-                "is_binary": are_binary.get(name, None)
-            })
+            result.append(
+                {
+                    "x": line[0],
+                    "y": line[1],
+                    "to": name,
+                    # if file was renamed, next line contains original path
+                    "from": next(line_iterable) if line[0] == "R" else name,
+                    "is_binary": are_binary.get(name, None),
+                }
+            )
         return {"code": code, "files": result}
 
     async def log(self, current_path, history_count=10):
@@ -336,7 +358,8 @@ class Git:
             ("-%d" % history_count),
         ]
         code, my_output, my_error = await execute(
-            cmd, cwd=os.path.join(self.root_dir, current_path),
+            cmd,
+            cwd=os.path.join(self.root_dir, current_path),
         )
         if code != 0:
             return {"code": code, "command": " ".join(cmd), "message": my_error}
@@ -376,7 +399,8 @@ class Git:
         """
         cmd = ["git", "log", "-1", "--numstat", "--oneline", "-z", selected_hash]
         code, my_output, my_error = await execute(
-            cmd, cwd=os.path.join(self.root_dir, current_path),
+            cmd,
+            cwd=os.path.join(self.root_dir, current_path),
         )
 
         if code != 0:
@@ -388,11 +412,11 @@ class Git:
         line_iterable = iter(strip_and_split(my_output)[1:])
         for line in line_iterable:
             is_binary = line.startswith("-\t-\t")
-            insertions, deletions, file = line.split('\t')
-            insertions = insertions.replace('-', '0')
-            deletions = deletions.replace('-', '0')
+            insertions, deletions, file = line.split("\t")
+            insertions = insertions.replace("-", "0")
+            deletions = deletions.replace("-", "0")
 
-            if file == '':
+            if file == "":
                 # file was renamed or moved, we need next two lines of output
                 from_path = next(line_iterable)
                 to_path = next(line_iterable)
@@ -402,20 +426,23 @@ class Git:
                 modified_file_name = file.split("/")[-1]
                 modified_file_path = file
 
-            result.append({
-                "modified_file_path": modified_file_path,
-                "modified_file_name": modified_file_name,
-                "insertion": insertions,
-                "deletion": deletions,
-                "is_binary": is_binary
-            })
+            result.append(
+                {
+                    "modified_file_path": modified_file_path,
+                    "modified_file_name": modified_file_name,
+                    "insertion": insertions,
+                    "deletion": deletions,
+                    "is_binary": is_binary,
+                }
+            )
             total_insertions += int(insertions)
             total_deletions += int(deletions)
 
         modified_file_note = "{num_files} files changed, {insertions} insertions(+), {deletions} deletions(-)".format(
             num_files=len(result),
             insertions=total_insertions,
-            deletions=total_deletions)
+            deletions=total_deletions,
+        )
 
         return {
             "code": code,
@@ -559,9 +586,7 @@ class Git:
 
         results = []
         try:
-            for name, commit_sha in (
-                line.split("\t") for line in output.splitlines()
-            ):
+            for name, commit_sha in (line.split("\t") for line in output.splitlines()):
                 results.append(
                     {
                         "is_current_branch": False,
@@ -664,7 +689,7 @@ class Git:
 
         untracked = []
         for f in status["files"]:
-            if f["x"]=="?" and f["y"]=="?":
+            if f["x"] == "?" and f["y"] == "?":
                 untracked.append(f["from"].strip('"'))
 
         return await self.add(untracked, top_repo_path)
@@ -721,7 +746,8 @@ class Git:
         """
         cmd = ["git", "checkout", "-b", branchname, startpoint]
         code, my_output, my_error = await execute(
-            cmd, cwd=os.path.join(self.root_dir, current_path),
+            cmd,
+            cwd=os.path.join(self.root_dir, current_path),
         )
         if code == 0:
             return {"code": code, "message": my_output}
@@ -830,14 +856,19 @@ class Git:
 
         if code != 0:
             output = output.strip()
-            has_conflict = "automatic merge failed; fix conflicts and then commit the result." in output.lower()
+            has_conflict = (
+                "automatic merge failed; fix conflicts and then commit the result."
+                in output.lower()
+            )
             if cancel_on_conflict and has_conflict:
                 code, _, error = await execute(
                     ["git", "merge", "--abort"],
-                    cwd=os.path.join(self.root_dir, curr_fb_path)
+                    cwd=os.path.join(self.root_dir, curr_fb_path),
                 )
                 if code == 0:
-                    response["message"] = "Unable to pull latest changes as doing so would result in a merge conflict. In order to push your local changes, you may want to consider creating a new branch based on your current work and pushing the new branch. Provided your repository is hosted (e.g., on GitHub), once pushed, you can create a pull request against the original branch on the remote repository and manually resolve the conflicts during pull request review."
+                    response[
+                        "message"
+                    ] = "Unable to pull latest changes as doing so would result in a merge conflict. In order to push your local changes, you may want to consider creating a new branch based on your current work and pushing the new branch. Provided your repository is hosted (e.g., on GitHub), once pushed, you can create a pull request against the original branch on the remote repository and manually resolve the conflicts during pull request review."
                 else:
                     response["message"] = error.strip()
             elif has_conflict:
@@ -850,7 +881,7 @@ class Git:
     async def push(self, remote, branch, curr_fb_path, auth=None, set_upstream=False):
         """
         Execute `git push $UPSTREAM $BRANCH`. The choice of upstream and branch is up to the caller.
-        """        
+        """
         command = ["git", "push"]
         if set_upstream:
             command.append("--set-upstream")
@@ -887,16 +918,19 @@ class Git:
         """
         cmd = ["git", "init"]
         cwd = os.path.join(self.root_dir, current_path)
-        code, _, error = await execute(
-            cmd, cwd=cwd
-        )
+        code, _, error = await execute(cmd, cwd=cwd)
 
         actions = None
         if code == 0:
-            code, actions = await self._maybe_run_actions('post_init', cwd)
+            code, actions = await self._maybe_run_actions("post_init", cwd)
 
         if code != 0:
-            return {"code": code, "command": " ".join(cmd), "message": error, "actions": actions}
+            return {
+                "code": code,
+                "command": " ".join(cmd),
+                "message": error,
+                "actions": actions,
+            }
         return {"code": code, "actions": actions}
 
     async def _maybe_run_actions(self, name, cwd):
@@ -908,24 +942,26 @@ class Git:
             for action in actions_list:
                 try:
                     # We trust the actions as they were passed via a config and not the UI
-                    code, stdout, stderr = await execute(
-                        shlex.split(action), cwd=cwd
+                    code, stdout, stderr = await execute(shlex.split(action), cwd=cwd)
+                    actions.append(
+                        {
+                            "cmd": action,
+                            "code": code,
+                            "stdout": stdout,
+                            "stderr": stderr,
+                        }
                     )
-                    actions.append({
-                        'cmd': action,
-                        'code': code,
-                        'stdout': stdout,
-                        'stderr': stderr
-                    })
                     # After any failure, stop
                 except Exception as e:
                     code = 1
-                    actions.append({
-                        'cmd': action,
-                        'code': 1,
-                        'stdout': None,
-                        'stderr': 'Exception: {}'.format(e)
-                    })
+                    actions.append(
+                        {
+                            "cmd": action,
+                            "code": 1,
+                            "stdout": None,
+                            "stderr": "Exception: {}".format(e),
+                        }
+                    )
                 if code != 0:
                     break
 
@@ -960,8 +996,7 @@ class Git:
             )
 
     async def _get_current_branch_detached(self, current_path):
-        """Execute 'git branch -a' to get current branch details in case of detached HEAD
-        """
+        """Execute 'git branch -a' to get current branch details in case of detached HEAD"""
         command = ["git", "branch", "-a"]
         code, output, error = await execute(
             command, cwd=os.path.join(self.root_dir, current_path)
@@ -1004,8 +1039,12 @@ class Git:
             return {"code": code, "command": " ".join(command), "message": error}
 
         remote_name = output.strip()
-        remote_branch = rev_parse_output.strip().lstrip(remote_name+"/")
-        return {"code": code, "remote_short_name": remote_name, "remote_branch": remote_branch}
+        remote_branch = rev_parse_output.strip().lstrip(remote_name + "/")
+        return {
+            "code": code,
+            "remote_short_name": remote_name,
+            "remote_branch": remote_branch,
+        }
 
     async def _get_tag(self, current_path, commit_sha):
         """Execute 'git describe commit_sha' to get
@@ -1046,6 +1085,7 @@ class Git:
                 "fatal: Path '{}' does not exist (neither on disk nor in the index)".format(
                     filename
                 ),
+                "fatal: Path '{}' does not exist in '{}'".format(filename, ref),
             ],
         )
         lower_error = error.lower()
@@ -1065,35 +1105,57 @@ class Git:
         Get the file content of filename.
         """
         relative_repo = os.path.relpath(top_repo_path, self.root_dir)
-        model = self.contents_manager.get(path=os.path.join(relative_repo, filename))
+        try:
+            model = self.contents_manager.get(
+                path=os.path.join(relative_repo, filename)
+            )
+        except tornado.web.HTTPError as error:
+            # Handle versioned file being deleted case
+            if error.status_code == 404 and error.log_message.startswith(
+                "No such file or directory: "
+            ):
+                return ""
+            raise error
         return model["content"]
 
     async def diff_content(self, filename, prev_ref, curr_ref, top_repo_path):
         """
         Collect get content of prev and curr and return.
         """
-        is_binary = await self._is_binary(filename, prev_ref["git"], top_repo_path)
-        if is_binary:
-            raise tornado.web.HTTPError(log_message="Error occurred while executing command to retrieve plaintext diff as file is not UTF-8.")
+        if prev_ref["git"]:
+            is_binary = await self._is_binary(filename, prev_ref["git"], top_repo_path)
+            if is_binary:
+                raise tornado.web.HTTPError(
+                    log_message="Error occurred while executing command to retrieve plaintext diff as file is not UTF-8."
+                )
+
+            prev_content = await self.show(filename, prev_ref["git"], top_repo_path)
+        else:
+            prev_content = ""
 
-        prev_content = await self.show(filename, prev_ref["git"], top_repo_path)
         if "special" in curr_ref:
             if curr_ref["special"] == "WORKING":
                 curr_content = self.get_content(filename, top_repo_path)
             elif curr_ref["special"] == "INDEX":
                 is_binary = await self._is_binary(filename, "INDEX", top_repo_path)
                 if is_binary:
-                    raise tornado.web.HTTPError(log_message="Error occurred while executing command to retrieve plaintext diff as file is not UTF-8.")
+                    raise tornado.web.HTTPError(
+                        log_message="Error occurred while executing command to retrieve plaintext diff as file is not UTF-8."
+                    )
 
                 curr_content = await self.show(filename, "", top_repo_path)
             else:
                 raise tornado.web.HTTPError(
-                    log_message="Error while retrieving plaintext diff, unknown special ref '{}'.".format(curr_ref["special"])
+                    log_message="Error while retrieving plaintext diff, unknown special ref '{}'.".format(
+                        curr_ref["special"]
+                    )
                 )
         else:
             is_binary = await self._is_binary(filename, curr_ref["git"], top_repo_path)
             if is_binary:
-                raise tornado.web.HTTPError(log_message="Error occurred while executing command to retrieve plaintext diff as file is not UTF-8.")
+                raise tornado.web.HTTPError(
+                    log_message="Error occurred while executing command to retrieve plaintext diff as file is not UTF-8."
+                )
 
             curr_content = await self.show(filename, curr_ref["git"], top_repo_path)
 
@@ -1121,20 +1183,42 @@ class Git:
             HTTPError: if git command failed
         """
         if ref == "INDEX":
-            command = ["git", "diff", "--numstat", "--cached", "4b825dc642cb6eb9a060e54bf8d69288fbee4904", "--", filename]
+            command = [
+                "git",
+                "diff",
+                "--numstat",
+                "--cached",
+                "4b825dc642cb6eb9a060e54bf8d69288fbee4904",
+                "--",
+                filename,
+            ]
         else:
-            command = ["git", "diff", "--numstat", "4b825dc642cb6eb9a060e54bf8d69288fbee4904", ref, "--", filename]  # where 4b825... is a magic SHA which represents the empty tree
+            command = [
+                "git",
+                "diff",
+                "--numstat",
+                "4b825dc642cb6eb9a060e54bf8d69288fbee4904",
+                ref,
+                "--",
+                filename,
+            ]  # where 4b825... is a magic SHA which represents the empty tree
         code, output, error = await execute(command, cwd=top_repo_path)
 
         if code != 0:
-            err_msg = "fatal: Path '{}' does not exist (neither on disk nor in the index)".format(filename).lower()
+            err_msg = "fatal: Path '{}' does not exist (neither on disk nor in the index)".format(
+                filename
+            ).lower()
             if err_msg in error.lower():
                 return False
 
-            raise tornado.web.HTTPError(log_message="Error while determining if file is binary or text '{}'.".format(error))
+            raise tornado.web.HTTPError(
+                log_message="Error while determining if file is binary or text '{}'.".format(
+                    error
+                )
+            )
 
         # For binary files, `--numstat` outputs two `-` characters separated by TABs:
-        return output.startswith('-\t-\t')
+        return output.startswith("-\t-\t")
 
     async def remote_add(self, top_repo_path, url, name=DEFAULT_REMOTE_NAME):
         """Handle call to `git remote add` command.
@@ -1148,11 +1232,8 @@ class Git:
         """
         cmd = ["git", "remote", "add", name, url]
         code, _, error = await execute(cmd, cwd=top_repo_path)
-        response = {
-                "code": code,
-                "command": " ".join(cmd)
-            }
-        
+        response = {"code": code, "command": " ".join(cmd)}
+
         if code != 0:
             response["message"] = error
 
@@ -1162,16 +1243,13 @@ class Git:
         """Handle call to `git remote show` command.
         Args:
             path (str): Git repository path
-        
+
         Returns:
             List[str]: Known remotes
         """
         command = ["git", "remote", "show"]
         code, output, error = await execute(command, cwd=path)
-        response = {
-                "code": code,
-                "command": " ".join(command)
-            }
+        response = {"code": code, "command": " ".join(command)}
         if code == 0:
             response["remotes"] = [r.strip() for r in output.splitlines()]
         else:
@@ -1180,22 +1258,22 @@ class Git:
         return response
 
     async def ensure_gitignore(self, top_repo_path):
-        """Handle call to ensure .gitignore file exists and the 
+        """Handle call to ensure .gitignore file exists and the
         next append will be on a new line (this means an empty file
         or a file ending with \n).
 
         top_repo_path: str
             Top Git repository path
         """
-        try:            
+        try:
             gitignore = pathlib.Path(top_repo_path) / ".gitignore"
             if not gitignore.exists():
                 gitignore.touch()
             elif gitignore.stat().st_size > 0:
                 content = gitignore.read_text()
-                if (content[-1] != "\n"):
+                if content[-1] != "\n":
                     with gitignore.open("a") as f:
-                        f.write('\n')
+                        f.write("\n")
         except BaseException as error:
             return {"code": -1, "message": str(error)}
         return {"code": 0}
@@ -1206,7 +1284,7 @@ class Git:
         top_repo_path: str
             Top Git repository path
         file_path: str
-            The path of the file in .gitignore 
+            The path of the file in .gitignore
         """
         try:
             res = await self.ensure_gitignore(top_repo_path)
@@ -1229,7 +1307,7 @@ class Git:
         if code == 0:
             version = GIT_VERSION_REGEX.match(output)
             if version is not None:
-                return version.group('version')
+                return version.group("version")
 
         return None
 
@@ -1240,7 +1318,9 @@ class Git:
             Git path repository
         """
         command = ["git", "tag", "--list"]
-        code, output, error = await execute(command, cwd=os.path.join(self.root_dir, current_path))
+        code, output, error = await execute(
+            command, cwd=os.path.join(self.root_dir, current_path)
+        )
         if code != 0:
             return {"code": code, "command": " ".join(command), "message": error}
         tags = [tag for tag in output.split("\n") if len(tag) > 0]
@@ -1255,7 +1335,9 @@ class Git:
             Tag to checkout
         """
         command = ["git", "checkout", "tags/" + tag]
-        code, _, error = await execute(command, cwd=os.path.join(self.root_dir, current_path))
+        code, _, error = await execute(
+            command, cwd=os.path.join(self.root_dir, current_path)
+        )
         if code == 0:
             return {"code": code, "message": "Tag {} checked out".format(tag)}
         else:
