@@ -4,7 +4,13 @@ import json
 from typing import List
 from unittest.mock import patch
 
+try:
+    from unittest.mock import AsyncMock  # New in Python 3.8 and used by unittest.mock
+except ImportError:
+    AsyncMock = None
+
 import requests
+import tornado
 from traitlets.config import Config
 
 # Shim for notebook server or jupyter_server
@@ -77,9 +83,15 @@ class ServerTest(ServerTestBase):
 
 
 class FakeContentManager:
-
     def __init__(self, root_dir):
         self.root_dir = root_dir
-    
+
     def get(self, path=None):
         return {"content": ""}
+
+
+def maybe_future(args):
+    if AsyncMock is None:
+        return tornado.gen.maybe_future(args)
+    else:
+        return args
